function love.load()
	sphere = love.graphics.newPixelEffect [[
		const number pi = 3.14159265;
		const number pi2 = 2.0 * pi;

		extern number time;
			  
		vec4 effect(vec4 color, Image texture, vec2 tc, vec2 pixel_coords)
		{
		   vec2 p = 2.0 * (tc - 0.5);
		   
		   number r = sqrt(p.x*p.x + p.y*p.y);

		   if (r > 1.0) discard;
		   
		   number d = r != 0.0 ? asin(r) / r : 0.0;
					
		   vec2 p2 = d * p;
		   
		   number x3 = mod(p2.x / (pi2) + 0.5 + time, 1.0);
		   number y3 = p2.y / (pi2) + 0.5;
		   
		   vec2 newCoord = vec2(x3, y3);
		   
		   vec4 sphereColor = color * Texel(texture, newCoord);
					
		   return sphereColor;
		}
	]]
	
	shaderOn = false
	planetCanvas = love.graphics.newCanvas(800, 600)
	
	planetTypes = {}
	planetTypes[1] = "desert"
	planetTypes[2] = "lava"
	planetTypes[3] = "frozen"
	planetTypes[4] = "earth"
	planetTypes[5] = "rock"
	planetTypes[6] = "gas"
	
	tiles = {}
	tiles[0] = love.graphics.newImage("water.png")
	tiles[1] = love.graphics.newImage("land.png")
	
	planets = {}
end

function love.update(dt)
end

function love.draw()
	if shaderOn then
		love.graphics.setPixelEffect(sphere)
	else
		love.graphics.setPixelEffect()
	end
	
	love.graphics.draw(planetCanvas)
end

function love.keypressed(key, uni)
	if key == " " then
		planets = {}
		generatePlanet()
	end
	
	if key == "z" then
		if shaderOn then
			shaderOn = false
		else
			shaderOn = true
		end
	end
end

function generatePlanet()
	local i = {}
	
	i.type = planetTypes[math.random(1, #planetTypes)]
	i.size = math.random(1, 8)
	
	i.grid = {}
	for x = 1, 8 * i.size do
		i.grid[x] = {}
		for y = 1, 8 * i.size do
			i.grid[x][y] = math.random(1, 2) - 1
		end
	end
	
	table.insert(planets, i)
	
	planetCanvas = love.graphics.newCanvas(i.size * 8 * 32, i.size * 8 * 32)
	love.graphics.setCanvas(planetCanvas)
		planetCanvas:clear()
			for i,v in ipairs(planets) do
				for x = 1, 8 * v.size do
					for y = 1, 8 * v.size do
						love.graphics.draw(tiles[v.grid[x][y]], ((i * 32) - 32) + x * 32, y * 32)
					end
				end
			end
	love.graphics.setCanvas()
end